@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2002 Peter Miller;
+ *	Copyright (C) 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,9 @@
 #ifndef COMMON_AC_GRP_H
 #define COMMON_AC_GRP_H
 
-#include <config.h>
+/* MacOS X needs sys/types.h before grp.h */
+#include <ac/sys/types.h>
+
 #include <grp.h>
 
 #endif /* COMMON_AC_GRP_H */
