@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,10 +38,9 @@
 #ifndef HAVE_GETTEXT
 
 char *
-gettext(s)
-	const char	*s;
+gettext(const char *s)
 {
-	return (char *)s;
+    return (char *)s;
 }
 
 #endif /* !HAVE_GETTEXT */
