@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1994, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,9 +33,4 @@
 #define offsetof(a, b)	((size_t)((char *)&((a *)0)->b - (char *)0))
 #endif
 
-#ifndef HAVE_WINT_T
-#define HAVE_WINT_T
-typedef wchar_t wint_t;
-#endif
-
 #endif /* COMMON_AC_STDDEF_H */
