@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,17 +31,16 @@
  */
 
 int
-rename(oldname, newname)
-	char	*oldname;		/* old file name */
-	char	*newname;		/* new file name */
+rename(char *oldname, char *newname)
 {
-	if (link(oldname, newname) < 0)
-		return -1;
-	if (unlink(oldname) < 0) {
-		unlink(newname);
-		return -1;
-	}
-	return 0;
+    if (link(oldname, newname) < 0)
+       	return -1;
+    if (unlink(oldname) < 0)
+    {
+       	unlink(newname);
+       	return -1;
+    }
+    return 0;
 }
 
 #endif
