@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1994, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1998, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,7 @@
 #endif
 
 #ifdef HAVE_UNISTD_H
-#include <sys/types.h>
+#include <ac/sys/types.h>
 #include <unistd.h>
 #endif
 
