@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -54,10 +54,10 @@ struct arglex_value_ty
 extern arglex_token_ty arglex_token;
 extern arglex_value_ty arglex_value;
 
-void arglex_init _((int, char **, arglex_table_ty *));
-arglex_token_ty arglex _((void));
-int arglex_compare _((const char *formal, const char *actual));
+void arglex_init(int, char **, arglex_table_ty *);
+arglex_token_ty arglex(void);
+int arglex_compare(const char *formal, const char *actual);
 
-char *arglex_token_name _((arglex_token_ty));
+char *arglex_token_name(arglex_token_ty);
 
 #endif /* ARGLEX_H */
