@@ -1361,13 +1361,21 @@ fcomp(char *nameA, char *nameB)
     {
 	readfile(&fc.fileA, fc.fileAskip, fc.fileAmodify);
 	if (fc.fileA.is_binary)
+	{
 	    binary_warning(nameA);
+	    if (fc.cant_do_binary)
+		return;
+	}
     }
     if (nameB)
     {
 	readfile(&fc.fileB, fc.fileBskip, fc.fileBmodify);
 	if (fc.fileB.is_binary)
+	{
 	    binary_warning(nameB);
+	    if (fc.cant_do_binary)
+		return;
+	}
     }
     changes = fc.fileA.f_linecount - fc.fileB.f_linecount;
     if (changes < 0)
