@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,8 +29,8 @@
  * internationalized error messages
  * (also the keywords necessary to pull out the msgid strings)
  */
-void error_intl _((sub_context_ty *, char *));
-void fatal_intl _((sub_context_ty *, char *));
-void verbose_intl _((sub_context_ty *, char *));
+void error_intl(sub_context_ty *, const char *);
+void fatal_intl(sub_context_ty *, const char *) ATTR_NORETURN;
+void verbose_intl(sub_context_ty *, const char *);
 
 #endif /* COMMON_ERROR_INTL_H */
