@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998, 2002 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2002, 2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,4 +28,10 @@
 void help(char *, void (*usage)(void));
 void bad_argument(void(*)(void));
 
+/**
+  * The mutually_exclusive function is used to complain abut the user
+  * specifying two mutually exclusive command line options.
+  */
+void mutually_exclusive(int arg1, int arg2, void (*usage)(void));
+
 #endif /* HELP_H */
