@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,7 @@
 
 
 input_ty *
-input_file_text_open(fn)
-	const char	*fn;
+input_file_text_open(const char *fn)
 {
-	return input_crlf(input_file_open(fn), 1);
+    return input_crlf(input_file_open(fn), 1);
 }
