@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <input.h>
 
-input_ty *input_file_text_open _((const char *));
+input_ty *input_file_text_open(const char *);
 
 #endif /* COMMON_INPUT_FILE_TEXT_H */
