@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,8 @@
 
 #include <input.h>
 
-input_ty *input_new _((input_vtbl_ty *));
-long input_generic_read _((input_ty *, void *, long));
-void input_pushback_transfer _((input_ty *, input_ty *));
+input_ty *input_new(input_vtbl_ty *);
+long input_generic_read(input_ty *, void *, long);
+void input_pushback_transfer(input_ty *, input_ty *);
 
 #endif /* COMMON_INPUT_PRIVATE_H */
