@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,13 +24,11 @@
 
 
 void
-input_pushback_transfer(to, from)
-	input_ty	*to;
-	input_ty	*from;
+input_pushback_transfer(input_ty *to, input_ty *from)
 {
-	int		j;
+    int             j;
 
-	for (j = 0; j < from->pushback_len; ++j)
-		input_ungetc(to, from->pushback_buf[j]);
-	from->pushback_len = 0;
+    for (j = 0; j < from->pushback_len; ++j)
+	input_ungetc(to, from->pushback_buf[j]);
+    from->pushback_len = 0;
 }
