@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1999, 2002 Peter Miller;
+ *	Copyright (C) 1999, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,7 @@
  * MANIFEST: functions to determione directory-ness
  */
 
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <ac/sys/stat.h>
 
 #include <isdir.h>
 
