@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <main.h>
 
-int isdir _((const char *));
+int isdir(const char *);
 
 #endif /* COMMON_ISDIR_H */
