@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2002 Peter Miller;
+ *	Copyright (C) 1998, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -57,8 +57,8 @@ static state_ty state;
 void
 language_init(void)
 {
-    char            *lib;
-    char            *package;
+    const char      *lib;
+    const char      *package;
 
     if (state != state_uninitialized)
 	return;
@@ -83,7 +83,7 @@ language_init(void)
 #endif
     lib = getenv("FHIST_MESSAGE_LIBRARY");
     if (!lib || !*lib)
-	lib = library_directory_get();
+	lib = configured_nlsdir();
 #ifdef HAVE_SETLOCALE
 #ifdef HAVE_GETTEXT
     setlocale(LC_ALL, "");
