@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,8 @@
 
 #include <main.h>
 
-void language_init _((void));
-void language_human _((void));
-void language_C _((void));
+void language_init(void);
+void language_human(void);
+void language_C(void);
 
 #endif /* COMMON_LANGUAGE_H */
