@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2002 Peter Miller;
+ *	Copyright (C) 1998, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,9 @@
 
 #include <main.h>
 
-char *library_directory_get(void);
-char *data_directory_get(void);
-char *manual_directory_get(void);
+const char *configured_libdir(void);
+const char *configured_datadir(void);
+const char *configured_mandir(void);
+const char *configured_nlsdir(void);
 
 #endif /* COMMON_LIBDIR_H */
