@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,14 +24,12 @@
 #define MAIN_H
 
 /*
- * isolate ANSI C prototypes
+ * Function attributes.
  */
-#ifndef _
-#ifdef __STDC__
-#define _(x) x
+#ifdef __GNUC__
+#define ATTR_NORETURN __attribute__((noreturn))
 #else
-#define _(x) ()
-#endif
+#define ATTR_NORETURN
 #endif
 
 /*
