@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,10 +44,8 @@
  *	The memory_error function does not return.
  */
 
-static void memory_error _((void));
-
 static void
-memory_error()
+memory_error(void)
 {
 #ifdef DEBUG
 	nerror_raw("memory allocator");
@@ -76,8 +74,7 @@ memory_error()
  */
 
 void *
-mem_alloc(n)
-	size_t		n;
+mem_alloc(size_t n)
 {
 	void		*p;
 
@@ -109,8 +106,7 @@ mem_alloc(n)
  */
 
 void *
-mem_alloc_clear(n)
-	size_t		n;
+mem_alloc_clear(size_t n)
 {
 	void		*p;
 
@@ -121,9 +117,7 @@ mem_alloc_clear(n)
 
 
 void *
-mem_change_size(p, n)
-	void		*p;
-	size_t		n;
+mem_change_size(void *p, size_t n)
 {
 	if (n < 1)
 		n = 1;
@@ -139,16 +133,14 @@ mem_change_size(p, n)
 
 
 void
-mem_free(p)
-	void		*p;
+mem_free(void *p)
 {
 	free(p);
 }
 
 
 char *
-mem_copy_string(s)
-	const char	*s;
+mem_copy_string(const char *s)
 {
 	char		*cp;
 
