@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -66,10 +66,8 @@ static char	*tmp;
  *	The existing buffer is still valid after failure.
  */
 
-static int bigger _((void));
-
 static int
-bigger()
+bigger(void)
 {
 	char	*hold;
 	size_t	nbytes;
@@ -111,17 +109,9 @@ bigger()
  *	spec	- the formatting specifier specified
  */
 
-static void build_fake _((char *fake, int flag, int width, int precision,
-	int qualifier, int specifier));
-
 static void
-build_fake(fake, flag, width, precision, qualifier, specifier)
-	char		*fake;
-	int		flag;
-	int		width;
-	int		precision;
-	int		qualifier;
-	int		specifier;
+build_fake(char *fake, int flag, int width, int precision, int qualifier,
+	int specifier)
 {
 	char		*fp;
 
@@ -173,9 +163,7 @@ build_fake(fake, flag, width, precision, qualifier, specifier)
  */
 
 char *
-vmprintf_errok(fmt, ap)
-	const char	*fmt;
-	va_list		ap;
+vmprintf_errok(const char *fmt, va_list ap)
 {
 	int		width;
 	int		width_set;
@@ -666,14 +654,12 @@ vmprintf_errok(fmt, ap)
  */
 
 char *
-mprintf_errok(fmt sva_last)
-	const char	*fmt;
-	sva_last_decl
+mprintf_errok(const char *fmt, ...)
 {
 	char		*result;
 	va_list		ap;
 
-	sva_init(ap, fmt);
+	va_start(ap, fmt);
 	result = vmprintf_errok(fmt, ap);
 	va_end(ap);
 	return result;
@@ -708,9 +694,7 @@ mprintf_errok(fmt sva_last)
  */
 
 char *
-vmprintf(fmt, ap)
-	const char	*fmt;
-	va_list		ap;
+vmprintf(const char *fmt, va_list ap)
 {
 	char		*result;
 
@@ -749,14 +733,12 @@ vmprintf(fmt, ap)
  */
 
 char *
-mprintf(fmt sva_last)
-	const char	*fmt;
-	sva_last_decl
+mprintf(const char *fmt, ...)
 {
 	char		*result;
 	va_list		ap;
 
-	sva_init(ap, fmt);
+	va_start(ap, fmt);
 	result = vmprintf(fmt, ap);
 	va_end(ap);
 	return result;
@@ -790,9 +772,7 @@ mprintf(fmt sva_last)
  */
 
 string_ty *
-vmprintf_str(fmt, ap)
-	const char	*fmt;
-	va_list		ap;
+vmprintf_str(const char *fmt, va_list ap)
 {
 	if (!vmprintf_errok(fmt, ap))
 		nfatal_raw("mprintf \"%s\"", fmt);
