@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <output.h>
 
-output_ty *output_file_text_open _((const char *));
-output_ty *output_file_binary_open _((const char *));
+output_ty *output_file_text_open(const char *);
+output_ty *output_file_binary_open(const char *);
 
 #endif /* LIBAEGIS_OUTPUT_FILE_H */
