@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <output.h>
 
-output_ty *output_quoted_printable_decode _((output_ty *));
+output_ty *output_quoted_printable_decode(output_ty *, int);
 
 #endif /* COMMON_OUTPUT_QUOTPRINDECO_H */
