@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000, 2002 Peter Miller;
+ *	Copyright (C) 2000, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,7 @@
 
 #include <ac/stddef.h>
 #include <ac/stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <ac/sys/stat.h>
 
 #include <fcheck.h>
 #include <output/private.h>
