@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,9 +27,9 @@
 
 #define MAX_PAGE_WIDTH 2000
 
-void page_width_set _((int));
-int page_width_get _((void));
-void page_length_set _((int));
-int page_length_get _((void));
+void page_width_set(int);
+int page_width_get(void);
+void page_length_set(int);
+int page_length_get(void);
 
 #endif /* COMMON_PAGE_H */
