@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -40,21 +40,21 @@ struct string_ty
 	char		str_text[1];
 };
 
-void str_initialize _((void));
-string_ty *str_from_c _((const char *));
-string_ty *str_n_from_c _((const char *, size_t));
-string_ty *str_copy _((string_ty *));
-void str_free _((string_ty *));
-string_ty *str_catenate _((string_ty *, string_ty *));
-string_ty *str_cat_three _((string_ty *, string_ty *, string_ty *));
-int str_bool _((string_ty *));
-string_ty *str_upcase _((string_ty *));
-string_ty *str_downcase _((string_ty *));
-void str_dump _((void));
-string_ty *str_field _((string_ty *str, int sep, int fldnum));
-void slow_to_fast _((char **, string_ty **, size_t));
-string_ty *str_format _((const char *, ...)) ATTRIBUTE_FORMAT_1_2;
-string_ty *str_vformat _((const char *, va_list));
+void str_initialize(void);
+string_ty *str_from_c(const char *);
+string_ty *str_n_from_c(const char *, size_t);
+string_ty *str_copy(string_ty *);
+void str_free(string_ty *);
+string_ty *str_catenate(string_ty *, string_ty *);
+string_ty *str_cat_three(string_ty *, string_ty *, string_ty *);
+int str_bool(string_ty *);
+string_ty *str_upcase(string_ty *);
+string_ty *str_downcase(string_ty *);
+void str_dump(void);
+string_ty *str_field(string_ty *str, int sep, int fldnum);
+void slow_to_fast(char **, string_ty **, size_t);
+string_ty *str_format(const char *, ...) ATTRIBUTE_FORMAT_1_2;
+string_ty *str_vformat(const char *, va_list);
 
 #define str_equal(s1, s2) ((s1) == (s2))
 
