@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,7 @@
 #include <wstr_list.h>
 
 
-typedef wstring_ty *(*fp)_((sub_context_ty *, wstring_list_ty *));
+typedef wstring_ty *(*fp)(sub_context_ty *, wstring_list_ty *);
 
 typedef struct table_ty table_ty;
 struct table_ty
@@ -96,11 +96,8 @@ struct sub_context_ty
 };
 
 
-static void collect_constructor _((collect_ty *));
-
 static void
-collect_constructor(cp)
-	collect_ty	*cp;
+collect_constructor(collect_ty *cp)
 {
 	cp->buf = 0;
 	cp->size = 0;
@@ -108,11 +105,8 @@ collect_constructor(cp)
 }
 
 
-static void collect_destructor _((collect_ty *));
-
 static void
-collect_destructor(cp)
-	collect_ty	*cp;
+collect_destructor(collect_ty *cp)
 {
 	if (cp->buf)
 		mem_free(cp->buf);
@@ -137,12 +131,8 @@ collect_destructor(cp)
  *	c - the character being collected
  */
 
-static void collect _((collect_ty *, wchar_t));
-
 static void
-collect(cp, c)
-	collect_ty	*cp;
-	wchar_t		c;
+collect(collect_ty *cp, wchar_t c)
 {
 	if (cp->pos >= cp->size)
 	{
@@ -156,13 +146,8 @@ collect(cp, c)
 }
 
 
-static void collect_n _((collect_ty *, wchar_t *, size_t));
-
 static void
-collect_n(cp, s, n)
-	collect_ty	*cp;
-	wchar_t		*s;
-	size_t		n;
+collect_n(collect_ty *cp, wchar_t *s, size_t n)
 {
 	while (n > 0)
 	{
@@ -188,11 +173,8 @@ collect_n(cp, s, n)
  *	wstring_ty *; pointer to the string in dynamic memory.
  */
 
-static wstring_ty *collect_end _((collect_ty *));
-
 static wstring_ty *
-collect_end(cp)
-	collect_ty	*cp;
+collect_end(collect_ty *cp)
 {
 	wstring_ty	*result;
 
@@ -202,11 +184,8 @@ collect_end(cp)
 }
 
 
-static void sub_context_constructor _((sub_context_ty *));
-
 static void
-sub_context_constructor(scp)
-	sub_context_ty	*scp;
+sub_context_constructor(sub_context_ty *scp)
 {
 	trace(("sub_context_constructor()\n{\n"));
 	scp->diversion = 0;
@@ -220,7 +199,7 @@ sub_context_constructor(scp)
 
 
 sub_context_ty *
-sub_context_new()
+sub_context_new(void)
 {
 	sub_context_ty	*scp;
 	int		hang_on_a_second;
@@ -233,11 +212,8 @@ sub_context_new()
 }
 
 
-static void sub_context_destructor _((sub_context_ty *));
-
 static void
-sub_context_destructor(scp)
-	sub_context_ty	*scp;
+sub_context_destructor(sub_context_ty *scp)
 {
 	size_t		j;
 
@@ -256,8 +232,7 @@ sub_context_destructor(scp)
 
 
 void
-sub_context_delete(scp)
-	sub_context_ty	*scp;
+sub_context_delete(sub_context_ty *scp)
 {
 	sub_context_destructor(scp);
 	mem_free(scp);
@@ -265,9 +240,7 @@ sub_context_delete(scp)
 
 
 void
-sub_context_error_set(scp, s)
-	sub_context_ty	*scp;
-	char		*s;
+sub_context_error_set(sub_context_ty *scp, char *s)
 {
 	scp->suberr = s;
 }
@@ -315,17 +288,12 @@ static table_ty	table[] =
  *	s - string to take as input
  */
 
-static void sub_diversion _((sub_context_ty *, wstring_ty *, int));
-
 static void
-sub_diversion(scp, s, resubstitute)
-	sub_context_ty	*scp;
-	wstring_ty	*s;
-	int		resubstitute;
+sub_diversion(sub_context_ty *scp, wstring_ty *s, int resubstitute)
 {
 	diversion_ty	*dp;
 
-	trace(("sub_diversion(s = %8.8lX, resub = %d)\n{\n"/*}*/,
+	trace(("sub_diversion(s = %8.8lX, resub = %d)\n{\n",
 		(long)s, resubstitute));
 	dp = (diversion_ty *)mem_alloc(sizeof(diversion_ty));
 	dp->text = wstr_copy(s);
@@ -333,7 +301,7 @@ sub_diversion(scp, s, resubstitute)
 	dp->resubstitute = resubstitute;
 	dp->prev = scp->diversion;
 	scp->diversion = dp;
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -349,21 +317,18 @@ sub_diversion(scp, s, resubstitute)
  *	release a diversion when it has been exhausted.
  */
 
-static void sub_diversion_close _((sub_context_ty *));
-
 static void
-sub_diversion_close(scp)
-	sub_context_ty	*scp;
+sub_diversion_close(sub_context_ty *scp)
 {
 	diversion_ty	*dp;
 
-	trace(("sub_diversion_close()\n{\n"/*}*/));
+	trace(("sub_diversion_close()\n{\n"));
 	assert(scp->diversion);
 	dp = scp->diversion;
 	scp->diversion = dp->prev;
 	wstr_free(dp->text);
 	mem_free((char *)dp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -382,12 +347,8 @@ sub_diversion_close(scp)
  *	args - the name and arguments of the substitution
  */
 
-static void execute _((sub_context_ty *, wstring_list_ty *));
-
 static void
-execute(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
+execute(sub_context_ty *scp, wstring_list_ty *arg)
 {
 	string_ty	*cmd;
 	wstring_ty	*s;
@@ -396,7 +357,7 @@ execute(scp, arg)
 	table_ty	*tp;
 	long		j;
 
-	trace(("execute(scp = %08lX, arg = %08lX)\n{\n"/*}*/,
+	trace(("execute(scp = %08lX, arg = %08lX)\n{\n",
 		(long)scp, (long)arg));
 	if (arg->nitems == 0)
 	{
@@ -504,7 +465,7 @@ execute(scp, arg)
 		sub_context_delete(scp2);
 		str_free(s3);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -524,16 +485,13 @@ execute(scp, arg)
  *	int - the chacater, or NUL to indicate end of input
  */
 
-static wchar_t sub_getc_meta _((sub_context_ty *));
-
 static wchar_t
-sub_getc_meta(scp)
-	sub_context_ty	*scp;
+sub_getc_meta(sub_context_ty *scp)
 {
 	wchar_t		result;
 	diversion_ty	*dp;
 
-	trace(("sub_getc_meta()\n{\n"/*}*/));
+	trace(("sub_getc_meta()\n{\n"));
 	dp = scp->diversion;
 	if (!dp)
 		result = 0;
@@ -547,7 +505,7 @@ sub_getc_meta(scp)
 	else
 		trace(("return %4.4lX;\n", (long)result));
 #endif
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
@@ -570,16 +528,12 @@ sub_getc_meta(scp)
  *	Only push back what was read.
  */
 
-static void sub_getc_meta_undo _((sub_context_ty *, wchar_t));
-
 static void
-sub_getc_meta_undo(scp, c)
-	sub_context_ty	*scp;
-	wchar_t		c;
+sub_getc_meta_undo(sub_context_ty *scp, wchar_t c)
 {
 	diversion_ty	*dp;
 
-	trace(("sub_getc_meta_undo(%ld)\n{\n"/*}*/, (long)c));
+	trace(("sub_getc_meta_undo(%ld)\n{\n", (long)c));
 #ifdef DEBUG
 	if (iswprint(c) && c >= CHAR_MIN && c <= CHAR_MAX)
 		trace(("c = '%c'\n", (char)c));
@@ -596,7 +550,7 @@ sub_getc_meta_undo(scp, c)
 		dp->pos--;
 		assert(c == dp->text->wstr_text[dp->pos]);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -619,13 +573,10 @@ sub_getc_meta_undo(scp, c)
  *		or NUL if none.
  */
 
-static wchar_t sub_getc _((sub_context_ty *)); /* forward */
-
-static wchar_t dollar _((sub_context_ty *));
+static wchar_t sub_getc(sub_context_ty *); /* forward */
 
 static wchar_t
-dollar(scp)
-	sub_context_ty	*scp;
+dollar(sub_context_ty *scp)
 {
 	wstring_list_ty	arg;
 	int		result;
@@ -634,7 +585,7 @@ dollar(scp)
 	wchar_t		quoted;
 	collect_ty	tmp;
 
-	trace(("dollar()\n{\n"/*}*/));
+	trace(("dollar()\n{\n"));
 	collect_constructor(&tmp);
 	wstring_list_zero(&arg);
 	result = 0;
@@ -714,14 +665,14 @@ dollar(scp)
 		wstring_list_free(&arg);
 		break;
 
-	case '{'/*}*/:
+	case '{':
 		c = sub_getc(scp);
 		for (;;)
 		{
 			/*
 			 * look for terminator
 			 */
-			if (c == /*{*/'}')
+			if (c == '}')
 				break;
 
 			/*
@@ -771,7 +722,7 @@ dollar(scp)
 					}
 					break;
 				}
-				if (!quoted && (iswspace(c) || c == /*{*/'}'))
+				if (!quoted && (iswspace(c) || c == '}'))
 					break;
 				if (c == quoted)
 				{
@@ -830,7 +781,7 @@ dollar(scp)
 	else
 		trace(("return %4.4lX;\n", (long)result));
 #endif
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
@@ -852,15 +803,12 @@ dollar(scp)
  *		or NUL to indicate end of input.
  */
 
-static wchar_t sub_getc _((sub_context_ty *));
-
 static wchar_t
-sub_getc(scp)
-	sub_context_ty	*scp;
+sub_getc(sub_context_ty *scp)
 {
 	wchar_t		c;
 
-	trace(("sub_getc()\n{\n"/*}*/));
+	trace(("sub_getc()\n{\n"));
 	for (;;)
 	{
 		c = sub_getc_meta(scp);
@@ -875,25 +823,6 @@ sub_getc(scp)
 			sub_diversion_close(scp);
 			continue;
 
-#if 0
-		case '%':
-			c = sub_getc_meta(scp);
-			if (c != '%')
-			{
-				sub_context_ty	*scp2;
-
-				scp2 = sub_context_new();
-				fatal_intl
-				(
-					scp2,
-		i18n("the %% character must always be doubled in substitutions")
-				);
-				/* NOTREACHED */
-				sub_context_delete(sc2);
-			}
-			break;
-#endif
-
 		case '$':
 			if (!scp->diversion->resubstitute)
 				break;
@@ -910,17 +839,13 @@ sub_getc(scp)
 	else
 		trace(("return %4.4lX;\n", (long)c));
 #endif
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return c;
 }
 
 
-static wstring_ty *subst _((sub_context_ty *, wstring_ty *));
-
 static wstring_ty *
-subst(scp, s)
-	sub_context_ty	*scp;
-	wstring_ty	*s;
+subst(sub_context_ty *scp, wstring_ty *s)
 {
 	collect_ty	buf;
 	wchar_t		c;
@@ -929,7 +854,7 @@ subst(scp, s)
 	table_ty	*the_end;
 	int		error_count;
 
-	trace(("subst(scp = %08lX, s = %8.8lX)\n{\n"/*}*/,
+	trace(("subst(scp = %08lX, s = %8.8lX)\n{\n",
 		(long)scp, (long)s));
 	collect_constructor(&buf);
 	sub_diversion(scp, s, 1);
@@ -1040,21 +965,19 @@ subst(scp, s)
 	result = collect_end(&buf);
 	collect_destructor(&buf);
 	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
 
 wstring_ty *
-subst_intl_wide(scp, msg)
-	sub_context_ty	*scp;
-	const char	*msg;
+subst_intl_wide(sub_context_ty *scp, const char *msg)
 {
 	char		*tmp;
 	wstring_ty	*s;
 	wstring_ty	*result;
 
-	trace(("subst_intl_wide(scp = %08lX, msg = \"%s\")\n{\n"/*}*/,
+	trace(("subst_intl_wide(scp = %08lX, msg = \"%s\")\n{\n",
 		(long)scp, msg));
 	language_human();
 	tmp = gettext(msg);
@@ -1069,26 +992,24 @@ subst_intl_wide(scp, msg)
 	result = subst(scp, s);
 	wstr_free(s);
 	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
 
 string_ty *
-subst_intl(scp, s)
-	sub_context_ty	*scp;
-	const char	*s;
+subst_intl(sub_context_ty *scp, const char *s)
 {
 	wstring_ty	*result_wide;
 	string_ty	*result;
 
-	trace(("subst_intl(scp = %08lX, s = \"%s\")\n{\n"/*}*/,
+	trace(("subst_intl(scp = %08lX, s = \"%s\")\n{\n",
 		(long)scp, s));
 	result_wide = subst_intl_wide(scp, s);
 	result = wstr_to_str(result_wide);
 	wstr_free(result_wide);
 	trace(("return \"%s\";\n", result->str_text));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
@@ -1117,16 +1038,14 @@ subst_intl(scp, s)
  */
 
 string_ty *
-substitute(scp, s)
-	sub_context_ty	*scp;
-	string_ty	*s;
+substitute(sub_context_ty *scp, string_ty *s)
 {
 	wstring_ty	*ws;
 	wstring_ty	*result_wide;
 	string_ty	*result;
 
 	assert(s);
-	trace(("substitute(scp = %08lX, s = \"%s\")\n{\n"/*}*/,
+	trace(("substitute(scp = %08lX, s = \"%s\")\n{\n",
 		(long)scp, s->str_text));
 	ws = str_to_wstr(s);
 	result_wide = subst(scp, ws);
@@ -1134,7 +1053,7 @@ substitute(scp, s)
 	result = wstr_to_str(result_wide);
 	wstr_free(result_wide);
 	trace(("return \"%s\";\n", result->str_text));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return result;
 }
 
@@ -1153,17 +1072,16 @@ substitute(scp, s)
  */
 
 void
-sub_var_clear(scp)
-	sub_context_ty	*scp;
+sub_var_clear(sub_context_ty *scp)
 {
 	size_t		j;
 
-	trace(("sub_var_clear()\n{\n"/*}*/));
+	trace(("sub_var_clear()\n{\n"));
 	for (j = 0; j < scp->sub_var_pos; ++j)
 		wstr_free(scp->sub_var_list[j].value);
 	scp->sub_var_pos = 0;
 	scp->errno_sequester = 0;
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -1193,10 +1111,7 @@ sub_var_clear(scp)
  */
 
 void
-sub_var_set_string(scp, name, value)
-	sub_context_ty	*scp;
-	const char	*name;
-	string_ty	*value;
+sub_var_set_string(sub_context_ty *scp, const char *name, string_ty *value)
 {
 	table_ty	*svp;
 
@@ -1224,18 +1139,14 @@ sub_var_set_string(scp, name, value)
 
 
 void
-sub_var_set_format(scp, name, fmt sva_last)
-	sub_context_ty	*scp;
-	const char	*name;
-	const char	*fmt;
-	sva_last_decl
+sub_var_set_format(sub_context_ty *scp, const char *name, const char *fmt, ...)
 {
 	va_list		ap;
 	string_ty	*s;
 
 	trace(("sub_var_set_format(scp = %08lX, name = \"%s\")\n{\n",
 		(long)scp, name));
-	sva_init(ap, fmt);
+	va_start(ap, fmt);
 	s = str_vformat(fmt, ap);
 	va_end(ap);
 	sub_var_set_string(scp, name, s);
@@ -1245,20 +1156,14 @@ sub_var_set_format(scp, name, fmt sva_last)
 
 
 void
-sub_var_set_long(scp, name, value)
-	sub_context_ty	*scp;
-	const char	*name;
-	long		value;
+sub_var_set_long(sub_context_ty *scp, const char *name, long value)
 {
 	sub_var_set_format(scp, name, "%ld", value);
 }
 
 
 void
-sub_var_set_charstar(scp, name, value)
-	sub_context_ty	*scp;
-	const char	*name;
-	const char	*value;
+sub_var_set_charstar(sub_context_ty *scp, const char *name, const char *value)
 {
 	string_ty	*s;
 
@@ -1272,9 +1177,7 @@ sub_var_set_charstar(scp, name, value)
 
 
 void
-sub_var_resubstitute(scp, name)
-	sub_context_ty	*scp;
-	const char	*name;
+sub_var_resubstitute(sub_context_ty *scp, const char *name)
 {
 	table_ty	*the_end;
 	table_ty	*svp;
@@ -1290,9 +1193,7 @@ sub_var_resubstitute(scp, name)
 
 
 void
-sub_var_override(scp, name)
-	sub_context_ty	*scp;
-	const char	*name;
+sub_var_override(sub_context_ty *scp, const char *name)
 {
 	table_ty	*the_end;
 	table_ty	*svp;
@@ -1308,9 +1209,7 @@ sub_var_override(scp, name)
 
 
 void
-sub_var_optional(scp, name)
-	sub_context_ty	*scp;
-	const char	*name;
+sub_var_optional(sub_context_ty *scp, const char *name)
 {
 	table_ty	*the_end;
 	table_ty	*svp;
@@ -1326,9 +1225,7 @@ sub_var_optional(scp, name)
 
 
 void
-sub_var_append_if_unused(scp, name)
-	sub_context_ty	*scp;
-	const char	*name;
+sub_var_append_if_unused(sub_context_ty *scp, const char *name)
 {
 	table_ty	*the_end;
 	table_ty	*svp;
@@ -1347,25 +1244,21 @@ sub_var_append_if_unused(scp, name)
 
 
 void
-sub_errno_setx(scp, x)
-	sub_context_ty	*scp;
-	int		x;
+sub_errno_setx(sub_context_ty *scp, int x)
 {
 	scp->errno_sequester = x;
 }
 
 
 void
-sub_errno_set(scp)
-	sub_context_ty	*scp;
+sub_errno_set(sub_context_ty *scp)
 {
 	sub_errno_setx(scp, errno);
 }
 
 
 int
-sub_context_errno_get(scp)
-	sub_context_ty	*scp;
+sub_context_errno_get(sub_context_ty *scp)
 {
 	if (scp->errno_sequester == 0)
 		scp->errno_sequester = errno;
