@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,22 +29,22 @@
 struct string_ty;
 typedef struct sub_context_ty sub_context_ty;
 
-sub_context_ty *sub_context_new _((void));
-void sub_context_delete _((sub_context_ty *));
-void sub_var_clear _((sub_context_ty *));
-void sub_var_set_format _((sub_context_ty *, const char *name, const char *fmt, ...)) ATTRIBUTE_FORMAT_3_4;
-void sub_var_set_charstar _((sub_context_ty *, const char *name, const char *value));
-void sub_var_set_string _((sub_context_ty *, const char *name, struct string_ty *value));
-void sub_var_set_long _((sub_context_ty *, const char *name, long value));
-void sub_var_optional _((sub_context_ty *, const char *));
-void sub_var_append_if_unused _((sub_context_ty *, const char *));
-void sub_var_override _((sub_context_ty *, const char *));
-void sub_var_resubstitute _((sub_context_ty *, const char *));
-void sub_errno_set _((sub_context_ty *));
-void sub_errno_setx _((sub_context_ty *, int));
-struct string_ty *substitute _((sub_context_ty *, struct string_ty *));
-struct string_ty *subst_intl _((sub_context_ty *, const char *));
-struct wstring_ty *subst_intl_wide _((sub_context_ty *, const char *));
+sub_context_ty *sub_context_new(void);
+void sub_context_delete(sub_context_ty *);
+void sub_var_clear(sub_context_ty *);
+void sub_var_set_format(sub_context_ty *, const char *name, const char *fmt, ...) ATTRIBUTE_FORMAT_3_4;
+void sub_var_set_charstar(sub_context_ty *, const char *name, const char *value);
+void sub_var_set_string(sub_context_ty *, const char *name, struct string_ty *value);
+void sub_var_set_long(sub_context_ty *, const char *name, long value);
+void sub_var_optional(sub_context_ty *, const char *);
+void sub_var_append_if_unused(sub_context_ty *, const char *);
+void sub_var_override(sub_context_ty *, const char *);
+void sub_var_resubstitute(sub_context_ty *, const char *);
+void sub_errno_set(sub_context_ty *);
+void sub_errno_setx(sub_context_ty *, int);
+struct string_ty *substitute(sub_context_ty *, struct string_ty *);
+struct string_ty *subst_intl(sub_context_ty *, const char *);
+struct wstring_ty *subst_intl_wide(sub_context_ty *, const char *);
 
 /*
  * This macro does nothing by itself, but it serves as a keyword for the
