@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,9 @@
  */
 
 #include <ac/errno.h>
+#include <ac/grp.h>
+#include <ac/pwd.h>
 #include <ac/string.h>
-
-#include <pwd.h>
-#include <grp.h>
 #include <ac/unistd.h>
 
 #include <str.h>
@@ -60,57 +59,55 @@
  */
 
 wstring_ty *
-sub_errno(scp, arg)
-	sub_context_ty	*scp;
-	wstring_list_ty	*arg;
+sub_errno(sub_context_ty *scp, wstring_list_ty *arg)
 {
-	wstring_ty	*result;
+    wstring_ty      *result;
 
-	trace(("sub_errno()\n{\n"/*}*/));
-	if (arg->nitems != 1)
+    trace(("sub_errno()\n{\n"));
+    if (arg->nitems != 1)
+    {
+	sub_context_error_set(scp, i18n("requires zero arguments"));
+	result = 0;
+    }
+    else
+    {
+	int		n;
+
+	n = sub_context_errno_get(scp);
+	if (n == EPERM || n == EACCES)
 	{
-		sub_context_error_set(scp, i18n("requires zero arguments"));
-		result = 0;
+	    int             uid;
+	    struct passwd   *pw;
+	    string_ty       *uidn;
+	    int             gid;
+	    struct group    *gr;
+	    string_ty       *gidn;
+	    string_ty       *s;
+
+	    uid = geteuid();
+	    pw = getpwuid(uid);
+	    if (pw)
+		uidn = str_format("user \"%.8s\"", pw->pw_name);
+	    else
+		uidn = str_format("uid %d", uid);
+
+	    gid = getegid();
+	    gr = getgrgid(gid);
+	    if (gr)
+		gidn = str_format("group \"%.8s\"", gr->gr_name);
+	    else
+		gidn = str_format("gid %d", gid);
+
+	    s = str_format("%s [%S, %S]", strerror(n), uidn, gidn);
+	    str_free(uidn);
+	    str_free(gidn);
+	    result = str_to_wstr(s);
+	    str_free(s);
 	}
 	else
-	{
-		int		n;
-
-		n = sub_context_errno_get(scp);
-		if (n == EPERM || n == EACCES)
-		{
-			int		uid;
-			struct passwd	*pw;
-			string_ty	*uidn;
-			int		gid;
-			struct group	*gr;
-			string_ty	*gidn;
-			string_ty	*s;
-
-			uid = geteuid();
-			pw = getpwuid(uid);
-			if (pw)
-				uidn = str_format("user \"%.8s\"", pw->pw_name);
-			else
-				uidn = str_format("uid %d", uid);
-
-			gid = getegid();
-			gr = getgrgid(gid);
-			if (gr)
-				gidn = str_format("group \"%.8s\"", gr->gr_name);
-			else
-				gidn = str_format("gid %d", gid);
-
-			s = str_format("%s [%S, %S]", strerror(n), uidn, gidn);
-			str_free(uidn);
-			str_free(gidn);
-			result = str_to_wstr(s);
-			str_free(s);
-		}
-		else
-			result = wstr_from_c(strerror(n));
-	}
-	trace(("return %8.8lX;\n", (long)result));
-	trace((/*{*/"}\n"));
-	return result;
+	    result = wstr_from_c(strerror(n));
+    }
+    trace(("return %8.8lX;\n", (long)result));
+    trace(("}\n"));
+    return result;
 }
