@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998, 2001 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,22 +21,20 @@
  */
 
 #include <ac/stdio.h>
-#include <ac/stdlib.h>
 
 #include <arglex.h>
 #include <error.h>
 #include <help.h>
 #include <progname.h>
+#include <quit.h>
 #include <str.h>
 #include <trace.h>
 #include <version.h>
 #include <version_stmp.h>
 
 
-static void version_copyright _((void));
-
 static void
-version_copyright()
+version_copyright(void)
 {
 	static char *text[] =
 	{
@@ -66,12 +64,10 @@ version_copyright()
 }
 
 
-static void version_license _((void));
-
 static void
-version_license()
+version_license(void)
 {
-	help("fhist_lic", (void (*)_((void)))0);
+	help("fhist_lic", (void (*)(void))0);
 }
 
 
@@ -79,7 +75,7 @@ typedef struct table_ty table_ty;
 struct table_ty
 {
 	char	*name;
-	void	(*func)_((void));
+	void	(*func)(void);
 };
 
 
@@ -90,27 +86,25 @@ static	table_ty	table[] =
 };
 
 
-static void usage _((void));
-
 static void
-usage()
+usage(void)
 {
 	char		*progname;
 
 	progname = progname_get();
 	fprintf(stderr, "Usage: %s -VERSion [ name ]\n", progname);
 	fprintf(stderr, "       %s -Help\n", progname);
-	exit(1);
+	quit(1);
 }
 
 
 void
-version()
+version(void)
 {
-	void	(*func)_((void));
+	void	(*func)(void);
 	char	*name;
 
-	trace(("version()\n{\n"/*}*/));
+	trace(("version()\n{\n"));
 	arglex();
 	name = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -170,5 +164,5 @@ version()
 		func = version_copyright;
 
 	func();
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
