@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -75,12 +75,8 @@ static	int		changed;
  *	It is important that wstr_hash_ty be unsigned (int or long).
  */
 
-static wstr_hash_ty hash_generate _((const wchar_t *, size_t));
-
 static wstr_hash_ty
-hash_generate(s, n)
-	const wchar_t	*s;
-	size_t		n;
+hash_generate(const wchar_t *s, size_t n)
 {
 	wstr_hash_ty	retval;
 
@@ -118,10 +114,8 @@ hash_generate(s, n)
  *	This function must be called before any other defined in this file.
  */
 
-static void wstr_initialize _((void));
-
 static void
-wstr_initialize()
+wstr_initialize(void)
 {
 	wstr_hash_ty	j;
 
@@ -156,10 +150,8 @@ wstr_initialize()
  *	A load factor of about 80% is suggested.
  */
 
-static void split _((void));
-
 static void
-split()
+split(void)
 {
 	wstring_ty	*p;
 	wstring_ty	*p2;
@@ -225,8 +217,7 @@ split()
  */
 
 wstring_ty *
-wstr_from_c(s)
-	const char	*s;
+wstr_from_c(const char *s)
 {
 	return wstr_n_from_c(s, strlen(s));
 }
@@ -252,8 +243,7 @@ wstr_from_c(s)
  */
 
 wstring_ty *
-wstr_from_wc(ws)
-	const wchar_t	*ws;
+wstr_from_wc(const wchar_t *ws)
 {
 	return wstr_n_from_wc(ws, wcslen(ws));
 }
@@ -281,9 +271,7 @@ wstr_from_wc(ws)
  */
 
 wstring_ty *
-wstr_n_from_c(s, length)
-	const char	*s;
-	size_t		length;
+wstr_n_from_c(const char *s, size_t length)
 {
 #if __STDC__ >= 1
 	static char	escapes[] = "\aa\bb\ff\nn\rr\tt\vv";
@@ -405,10 +393,7 @@ wstr_n_from_c(s, length)
  */
 
 void
-wstr_to_mbs(s, result_p, result_length_p)
-	wstring_ty	*s;
-	char		**result_p;
-	size_t		*result_length_p;
+wstr_to_mbs(wstring_ty *s, char **result_p, size_t *result_length_p)
 {
 	static char	*buf;
 	static size_t	bufmax;
@@ -523,9 +508,7 @@ wstr_to_mbs(s, result_p, result_length_p)
  */
 
 wstring_ty *
-wstr_n_from_wc(s, length)
-	const wchar_t	*s;
-	size_t		length;
+wstr_n_from_wc(const wchar_t *s, size_t length)
 {
 	wstr_hash_ty	hash;
 	wstr_hash_ty	idx;
@@ -591,8 +574,7 @@ wstr_n_from_wc(s, length)
  */
 
 wstring_ty *
-wstr_copy(s)
-	wstring_ty	*s;
+wstr_copy(wstring_ty *s)
 {
 	s->wstr_references++;
 	return s;
@@ -618,8 +600,7 @@ wstr_copy(s)
  */
 
 void
-wstr_free(s)
-	wstring_ty	*s;
+wstr_free(wstring_ty *s)
 {
 	wstr_hash_ty	idx;
 	wstring_ty	**spp;
@@ -678,9 +659,7 @@ wstr_free(s)
  */
 
 wstring_ty *
-wstr_catenate(s1, s2)
-	wstring_ty	*s1;
-	wstring_ty	*s2;
+wstr_catenate(wstring_ty *s1, wstring_ty *s2)
 {
 	static wchar_t	*tmp;
 	static size_t	tmplen;
@@ -720,10 +699,7 @@ wstr_catenate(s1, s2)
  */
 
 wstring_ty *
-wstr_cat_three(s1, s2, s3)
-	wstring_ty	*s1;
-	wstring_ty	*s2;
-	wstring_ty	*s3;
+wstr_cat_three(wstring_ty *s1, wstring_ty *s2, wstring_ty *s3)
 {
 	static wchar_t	*tmp;
 	static size_t	tmplen;
@@ -755,8 +731,7 @@ wstr_cat_three(s1, s2, s3)
 
 
 wstring_ty *
-wstr_to_upper(ws)
-	const wstring_ty *ws;
+wstr_to_upper(const wstring_ty *ws)
 {
 	static wchar_t	*buffer;
 	static size_t	buflen;
@@ -783,8 +758,7 @@ wstr_to_upper(ws)
 
 
 wstring_ty *
-wstr_to_lower(ws)
-	const wstring_ty *ws;
+wstr_to_lower(const wstring_ty *ws)
 {
 	static wchar_t	*buffer;
 	static size_t	buflen;
@@ -811,8 +785,7 @@ wstr_to_lower(ws)
 
 
 wstring_ty *
-wstr_to_ident(ws)
-	const wstring_ty *ws;
+wstr_to_ident(const wstring_ty *ws)
 {
 	static wchar_t	*buffer;
 	static size_t	buflen;
@@ -843,16 +816,14 @@ wstr_to_ident(ws)
 
 
 wstring_ty *
-str_to_wstr(s)
-	string_ty	*s;
+str_to_wstr(string_ty *s)
 {
 	return wstr_n_from_c(s->str_text, s->str_length);
 }
 
 
 string_ty *
-wstr_to_str(ws)
-	wstring_ty	*ws;
+wstr_to_str(wstring_ty *ws)
 {
 	char		*text;
 	size_t		length;
@@ -886,9 +857,7 @@ wstr_to_str(ws)
 #endif
 
 int
-wstr_equal(s1, s2)
-	wstring_ty	*s1;
-	wstring_ty	*s2;
+wstr_equal(wstring_ty *s1, wstring_ty *s2)
 {
 	return (s1 == s2);
 }
