@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	fhist - file history and comparison tools
-#	Copyright (C) 1998, 1999 Peter Miller;
+#	Copyright (C) 1998, 1999, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -50,7 +50,7 @@ cat > $tmp/rpmrc << fubar
 macrofiles: ${mac}:$here/macros
 fubar
 
-rpm -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
+rpmbuild -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
 test $? -eq 0 || exit 1
 
 exit 0
