@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void breaksoff _((void));
-void breakson _((void));
+void breaksoff(void);
+void breakson(void);
 
 #endif /* UNIX_H */
