@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -52,12 +52,8 @@
  * output a message even if the files are identical.
  */
 void
-diffhistory(inputname, outputname, editname1, editname2, matchblab)
-	char		*inputname; /* name of file to be compared (or NULL) */
-	char		*outputname; /* output file (or NULL for terminal) */
-	char		*editname1; /* edit name of first file (or NULL) */
-	char		*editname2; /* edit name of second file (or NULL) */
-	int		matchblab;
+diffhistory(char *inputname, char *outputname, char *editname1, char *editname2,
+	int matchblab)
 {
 	long		edit1;	/* first edit number */
 	long		edit2;	/* second edit number */
@@ -190,13 +186,8 @@ diffhistory(inputname, outputname, editname1, editname2, matchblab)
  * The output files are text, by definition.
  */
 
-static int quickcomp _((char *nameA, char *nameB, long skipA));
-
 static int
-quickcomp(nameA, nameB, skipA)
-	char	*nameA;
-	char	*nameB;		/* file names to compare */
-	long	skipA;		/* number of lines to skip for file A */
+quickcomp(char *nameA, char *nameB, long skipA)
 {
 	FILE	*fpA;		/* first file */
 	FILE	*fpB;		/* second file */
@@ -263,8 +254,7 @@ quickcomp(nameA, nameB, skipA)
  */
 
 void
-cleanhistory(inputname)
-	char	*inputname;		/* name of file to be cleaned */
+cleanhistory(char *inputname)
 {
 	FILE	*fp;
 
@@ -335,8 +325,7 @@ i18n("file \"$filename\" differs from latest edit of module \"$module\"")
  * Check to see if a file is up to date, and report it if not.
  */
 void
-checkhistory(inputname)
-	char	*inputname;		/* name of file to be checked */
+checkhistory(char *inputname)
 {
 	FILE	*fp;
 
@@ -396,8 +385,7 @@ checkhistory(inputname)
  * immediately used to perform an update.
  */
 void
-comphistory(inputname)
-	char	*inputname;		/* name of file to be compared */
+comphistory(char *inputname)
 {
 	FILE	*fp;
 
