@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998-2002, 2004 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2002, 2004, 2006 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -112,6 +112,7 @@ enum
     arglex_token_prune,
     arglex_token_quick,
     arglex_token_remark,
+    arglex_token_remark_string,
     arglex_token_terminal,
     arglex_token_trace,
     arglex_token_update,
@@ -146,6 +147,7 @@ static arglex_table_ty argtab[] =
     {"-Path", arglex_token_path, },
     {"-Quick", arglex_token_quick, },
     {"-Remark", arglex_token_remark, },
+    {"-Remark_String", arglex_token_remark_string, },
     {"-Terminal", arglex_token_terminal, },
     {"-TRace", arglex_token_trace, },
     {"-Update", arglex_token_update, },
@@ -651,6 +653,7 @@ main(int argc, char **argv)
     editstring = NULL;
     editstring2 = NULL;
     sc.remarkname = NULL;
+    sc.remark_string = NULL;
 
     while (arglex_token != arglex_token_eoln)
     {
@@ -754,6 +757,16 @@ main(int argc, char **argv)
 	    sc.remarkname = expand(arglex_value.alv_string);
 	    break;
 
+	case arglex_token_remark_string:
+	    /* remark string */
+	    if (arglex() != arglex_token_string)
+	    {
+		sc.remark_string = NULL;
+		continue;
+	    }
+	    sc.remark_string = arglex_value.alv_string;
+	    break;
+
 	case arglex_token_terminal:
 	    /* type edit to terminal */
 	    action |= A_TYPE;
@@ -884,6 +897,8 @@ main(int argc, char **argv)
 	fatal_intl(0, i18n("multiple actions specified"));
     if (sc.remarkname && ((action & REMARK_ACTIONS) == 0))
 	fatal_intl(0, i18n("cannot use -Remark with specified action"));
+    if (sc.remark_string && ((action & REMARK_ACTIONS) == 0))
+	fatal_intl(0, i18n("cannot use -Remark_String with specified action"));
     if (inputname && ((action & INPUT_ACTIONS) == 0))
 	fatal_intl(0, i18n("cannot use -Input with specified action"));
     if (outputname && ((action & OUTPUT_ACTIONS) == 0))
