@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998, 2001 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 
 struct INFO;
 
-char *modifyline _((char *cp, long *linelen, struct INFO *info));
-long findedit _((char *inputname));
+char *modifyline(char *cp, long *linelen, struct INFO *info);
+long findedit(char *inputname, int is_bin);
 
 #endif /* MODLIN_H */
