@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <main.h>
 
-void prunehistory _((char *editname));
+void prunehistory(char *editname);
 
 #endif /* PRUNE_H */
