@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002, 2006 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -85,18 +85,27 @@ static void
 addhistory(FILE *fp, char *remarks, long editnumber)
 {
     time_t	    bintime;	/* binary time of day */
-    long	    len;	/* length of remark line */
+    int             column;
 
     time(&bintime);
     fprintf(fp, "%c %ld\n", T_BEGINEDIT, editnumber);
     fprintf(fp, "%c %s   %s", T_REMARK, get_user_login_name(), ctime(&bintime));
+    column = 0;
     while (*remarks)
     {
-	len = strlen(remarks);
-	fprintf(fp, "%c ", T_REMARK);
-	writefx(fp, remarks, len, sc.historyname);
-	remarks += (len + 1);
+	unsigned char c = *remarks++;
+	if (c == 0)
+	    break;
+	if (column == 0)
+	    fprintf(fp, "%c ", T_REMARK);
+	if (c == '\n')
+	    column = 0;
+	else
+	    column++;
+	putc(c, fp);
     }
+    if (column > 0)
+	putc('\n', fp);
     fprintf(fp, "%c 0\n", T_FILE);
     fprintf(fp, "%c %ld 0 0\n", T_ENDEDIT, editnumber);
 }
@@ -409,7 +418,12 @@ createhistory(char *inputname, char *editname)
     }
     undo_unlink(sc.sourcename);
     up = fopen_and_check(sc.sourcename, "wb");
-    remarks = getremarks(sc.modulename, sc.remarkname, 1L);
+    fprintf(stderr, "%s: %d: sc.remark_string = %p\n", __FILE__, __LINE__,
+	    sc.remark_string);
+    if (sc.remark_string)
+	remarks = sc.remark_string;
+    else
+	remarks = getremarks(sc.modulename, sc.remarkname, 1L);
 
     /*
      * Copy the original file into the history latest source file,
@@ -713,7 +727,10 @@ updatehistory(char *inputname, char *editname)
 	);
 	sub_context_delete(scp);
     }
-    remarks = getremarks(sc.modulename, sc.remarkname, newedit);
+    if (sc.remark_string)
+	remarks = sc.remark_string;
+    else
+	remarks = getremarks(sc.modulename, sc.remarkname, newedit);
 
     /*
      * See if we are doing a straight update, or an update after a
