@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	fhist - file history and comparison tools
-#	Copyright (C) 1999, 2003 Peter Miller;
+#	Copyright (C) 1999, 2003, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -47,6 +47,14 @@ pass()
 }
 trap "fail" 1 2 3 15
 
+#
+# use the built-in error messages
+#
+FHIST_MESSAGE_LIBRARY=$$work/no-such-dir
+export FHIST_MESSAGE_LIBRARY
+unset LANG
+unset LANGUAGE
+
 here=`pwd`
 if test $? -ne 0 ; then exit 1; fi
 mkdir $work
